==> cdk8s-plus-25-2.0.0-rc.8-sources.jar: org/cdk8s/plus25/AbstractPod.java <==
package org.cdk8s.plus25;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-18T03:10:48.879Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = org.cdk8s.plus25.$Module.class, fqn = "cdk8s-plus-25.AbstractPod")
public abstract class AbstractPod extends org.cdk8s.plus25.Resource implements org.cdk8s.plus25.IPodSelector, org.cdk8s.plus25.INetworkPolicyPeer, org.cdk8s.plus25.ISubject {

    protected AbstractPod(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AbstractPod(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected AbstractPod(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.Nullable org.cdk8s.plus25.AbstractPodProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), props });
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected AbstractPod(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     * @param cont This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull org.cdk8s.plus25.Container addContainer(final @org.jetbrains.annotations.NotNull org.cdk8s.plus25.ContainerProps cont) {
        return software.amazon.jsii.Kernel.call(this, "addContainer", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.Container.class), new Object[] { java.util.Objects.requireNonNull(cont, "cont is required") });
    }

    /**
     * @param hostAlias This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addHostAlias(final @org.jetbrains.annotations.NotNull org.cdk8s.plus25.HostAlias hostAlias) {
        software.amazon.jsii.Kernel.call(this, "addHostAlias", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(hostAlias, "hostAlias is required") });
    }

    /**
     * @param cont This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull org.cdk8s.plus25.Container addInitContainer(final @org.jetbrains.annotations.NotNull org.cdk8s.plus25.ContainerProps cont) {
        return software.amazon.jsii.Kernel.call(this, "addInitContainer", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.Container.class), new Object[] { java.util.Objects.requireNonNull(cont, "cont is required") });
    }

    /**
     * @param vol This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addVolume(final @org.jetbrains.annotations.NotNull org.cdk8s.plus25.Volume vol) {
        software.amazon.jsii.Kernel.call(this, "addVolume", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(vol, "vol is required") });
    }

    /**
     * Return the configuration of this peer.
     * <p>
     * @see <a href="INetworkPolicyPeer.toNetworkPolicyPeerConfig()">INetworkPolicyPeer.toNetworkPolicyPeerConfig()</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull org.cdk8s.plus25.NetworkPolicyPeerConfig toNetworkPolicyPeerConfig() {
        return software.amazon.jsii.Kernel.call(this, "toNetworkPolicyPeerConfig", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.NetworkPolicyPeerConfig.class));
    }

    /**
     * Convert the peer into a pod selector, if possible.
     * <p>
     * @see <a href="INetworkPolicyPeer.toPodSelector()">INetworkPolicyPeer.toPodSelector()</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.Nullable org.cdk8s.plus25.IPodSelector toPodSelector() {
        return software.amazon.jsii.Kernel.call(this, "toPodSelector", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.IPodSelector.class));
    }

    /**
     * Return the configuration of this selector.
     * <p>
     * @see <a href="IPodSelector.toPodSelectorConfig()">IPodSelector.toPodSelectorConfig()</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull org.cdk8s.plus25.PodSelectorConfig toPodSelectorConfig() {
        return software.amazon.jsii.Kernel.call(this, "toPodSelectorConfig", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.PodSelectorConfig.class));
    }

    /**
     * Return the subject configuration.
     * <p>
     * @see <a href="ISubect.toSubjectConfiguration()">ISubect.toSubjectConfiguration()</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull org.cdk8s.plus25.SubjectConfiguration toSubjectConfiguration() {
        return software.amazon.jsii.Kernel.call(this, "toSubjectConfiguration", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.SubjectConfiguration.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Boolean getAutomountServiceAccountToken() {
        return software.amazon.jsii.Kernel.get(this, "automountServiceAccountToken", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<org.cdk8s.plus25.Container> getContainers() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "containers", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.Container.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull org.cdk8s.plus25.PodDns getDns() {
        return software.amazon.jsii.Kernel.get(this, "dns", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.PodDns.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<org.cdk8s.plus25.HostAlias> getHostAliases() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "hostAliases", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.HostAlias.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<org.cdk8s.plus25.Container> getInitContainers() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "initContainers", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.Container.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.NotNull org.cdk8s.ApiObjectMetadataDefinition getPodMetadata();

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull org.cdk8s.plus25.PodSecurityContext getSecurityContext() {
        return software.amazon.jsii.Kernel.get(this, "securityContext", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.PodSecurityContext.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<org.cdk8s.plus25.Volume> getVolumes() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "volumes", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.Volume.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable org.cdk8s.plus25.DockerConfigSecret getDockerRegistryAuth() {
        return software.amazon.jsii.Kernel.get(this, "dockerRegistryAuth", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.DockerConfigSecret.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable org.cdk8s.plus25.RestartPolicy getRestartPolicy() {
        return software.amazon.jsii.Kernel.get(this, "restartPolicy", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.RestartPolicy.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable org.cdk8s.plus25.IServiceAccount getServiceAccount() {
        return software.amazon.jsii.Kernel.get(this, "serviceAccount", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.IServiceAccount.class));
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends org.cdk8s.plus25.AbstractPod implements org.cdk8s.plus25.IPodSelector.Jsii$Default, org.cdk8s.plus25.INetworkPolicyPeer.Jsii$Default, org.cdk8s.plus25.ISubject.Jsii$Default, org.cdk8s.plus25.IResource.Jsii$Default, org.cdk8s.plus25.IApiResource.Jsii$Default, org.cdk8s.plus25.IApiEndpoint.Jsii$Default, software.constructs.IConstruct.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * The underlying cdk8s API object.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        protected final @org.jetbrains.annotations.NotNull org.cdk8s.ApiObject getApiObject() {
            return software.amazon.jsii.Kernel.get(this, "apiObject", software.amazon.jsii.NativeType.forClass(org.cdk8s.ApiObject.class));
        }

        /**
         * The name of a resource type as it appears in the relevant API endpoint.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.NotNull java.lang.String getResourceType() {
            return software.amazon.jsii.Kernel.get(this, "resourceType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.NotNull org.cdk8s.ApiObjectMetadataDefinition getPodMetadata() {
            return software.amazon.jsii.Kernel.get(this, "podMetadata", software.amazon.jsii.NativeType.forClass(org.cdk8s.ApiObjectMetadataDefinition.class));
        }
    }
}

==> cdk8s-plus-25-2.0.33-sources.jar: org/cdk8s/plus25/AbstractPod.java <==
package org.cdk8s.plus25;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-11-21T02:50:30.018Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = org.cdk8s.plus25.$Module.class, fqn = "cdk8s-plus-25.AbstractPod")
public abstract class AbstractPod extends org.cdk8s.plus25.Resource implements org.cdk8s.plus25.IPodSelector, org.cdk8s.plus25.INetworkPolicyPeer, org.cdk8s.plus25.ISubject {

    protected AbstractPod(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AbstractPod(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected AbstractPod(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.Nullable org.cdk8s.plus25.AbstractPodProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), props });
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected AbstractPod(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required") });
    }

    /**
     * @param cont This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull org.cdk8s.plus25.Container addContainer(final @org.jetbrains.annotations.NotNull org.cdk8s.plus25.ContainerProps cont) {
        return software.amazon.jsii.Kernel.call(this, "addContainer", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.Container.class), new Object[] { java.util.Objects.requireNonNull(cont, "cont is required") });
    }

    /**
     * @param hostAlias This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addHostAlias(final @org.jetbrains.annotations.NotNull org.cdk8s.plus25.HostAlias hostAlias) {
        software.amazon.jsii.Kernel.call(this, "addHostAlias", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(hostAlias, "hostAlias is required") });
    }

    /**
     * @param cont This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull org.cdk8s.plus25.Container addInitContainer(final @org.jetbrains.annotations.NotNull org.cdk8s.plus25.ContainerProps cont) {
        return software.amazon.jsii.Kernel.call(this, "addInitContainer", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.Container.class), new Object[] { java.util.Objects.requireNonNull(cont, "cont is required") });
    }

    /**
     * @param vol This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addVolume(final @org.jetbrains.annotations.NotNull org.cdk8s.plus25.Volume vol) {
        software.amazon.jsii.Kernel.call(this, "addVolume", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(vol, "vol is required") });
    }

    /**
     * Return the configuration of this peer.
     * <p>
     * @see <a href="INetworkPolicyPeer.toNetworkPolicyPeerConfig()">INetworkPolicyPeer.toNetworkPolicyPeerConfig()</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull org.cdk8s.plus25.NetworkPolicyPeerConfig toNetworkPolicyPeerConfig() {
        return software.amazon.jsii.Kernel.call(this, "toNetworkPolicyPeerConfig", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.NetworkPolicyPeerConfig.class));
    }

    /**
     * Convert the peer into a pod selector, if possible.
     * <p>
     * @see <a href="INetworkPolicyPeer.toPodSelector()">INetworkPolicyPeer.toPodSelector()</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.Nullable org.cdk8s.plus25.IPodSelector toPodSelector() {
        return software.amazon.jsii.Kernel.call(this, "toPodSelector", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.IPodSelector.class));
    }

    /**
     * Return the configuration of this selector.
     * <p>
     * @see <a href="IPodSelector.toPodSelectorConfig()">IPodSelector.toPodSelectorConfig()</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull org.cdk8s.plus25.PodSelectorConfig toPodSelectorConfig() {
        return software.amazon.jsii.Kernel.call(this, "toPodSelectorConfig", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.PodSelectorConfig.class));
    }

    /**
     * Return the subject configuration.
     * <p>
     * @see <a href="ISubect.toSubjectConfiguration()">ISubect.toSubjectConfiguration()</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @Override
    public @org.jetbrains.annotations.NotNull org.cdk8s.plus25.SubjectConfiguration toSubjectConfiguration() {
        return software.amazon.jsii.Kernel.call(this, "toSubjectConfiguration", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.SubjectConfiguration.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.Boolean getAutomountServiceAccountToken() {
        return software.amazon.jsii.Kernel.get(this, "automountServiceAccountToken", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<org.cdk8s.plus25.Container> getContainers() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "containers", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.Container.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull org.cdk8s.plus25.PodDns getDns() {
        return software.amazon.jsii.Kernel.get(this, "dns", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.PodDns.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<org.cdk8s.plus25.HostAlias> getHostAliases() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "hostAliases", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.HostAlias.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<org.cdk8s.plus25.Container> getInitContainers() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "initContainers", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.Container.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected @org.jetbrains.annotations.NotNull java.lang.Boolean getIsolate() {
        return software.amazon.jsii.Kernel.get(this, "isolate", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.NotNull org.cdk8s.ApiObjectMetadataDefinition getPodMetadata();

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull org.cdk8s.plus25.PodSecurityContext getSecurityContext() {
        return software.amazon.jsii.Kernel.get(this, "securityContext", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.PodSecurityContext.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<org.cdk8s.plus25.Volume> getVolumes() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "volumes", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.Volume.class))));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable org.cdk8s.plus25.DockerConfigSecret getDockerRegistryAuth() {
        return software.amazon.jsii.Kernel.get(this, "dockerRegistryAuth", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.DockerConfigSecret.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable org.cdk8s.plus25.RestartPolicy getRestartPolicy() {
        return software.amazon.jsii.Kernel.get(this, "restartPolicy", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.RestartPolicy.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable org.cdk8s.plus25.IServiceAccount getServiceAccount() {
        return software.amazon.jsii.Kernel.get(this, "serviceAccount", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus25.IServiceAccount.class));
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends org.cdk8s.plus25.AbstractPod implements org.cdk8s.plus25.IPodSelector.Jsii$Default, org.cdk8s.plus25.INetworkPolicyPeer.Jsii$Default, org.cdk8s.plus25.ISubject.Jsii$Default, org.cdk8s.plus25.IResource.Jsii$Default, org.cdk8s.plus25.IApiResource.Jsii$Default, org.cdk8s.plus25.IApiEndpoint.Jsii$Default, software.constructs.IConstruct.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * The underlying cdk8s API object.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        protected final @org.jetbrains.annotations.NotNull org.cdk8s.ApiObject getApiObject() {
            return software.amazon.jsii.Kernel.get(this, "apiObject", software.amazon.jsii.NativeType.forClass(org.cdk8s.ApiObject.class));
        }

        /**
         * The name of a resource type as it appears in the relevant API endpoint.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.NotNull java.lang.String getResourceType() {
            return software.amazon.jsii.Kernel.get(this, "resourceType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.NotNull org.cdk8s.ApiObjectMetadataDefinition getPodMetadata() {
            return software.amazon.jsii.Kernel.get(this, "podMetadata", software.amazon.jsii.NativeType.forClass(org.cdk8s.ApiObjectMetadataDefinition.class));
        }
    }
}
